@@ -49,7 +49,20 @@ mod tests {
     #[test]
     fn escape_test() {
         let md = "<tag & test \\\\ \\a \\b \\c> '".to_string();
-        let html = "<p>&lt;tag &amp; test \\ a b c> &apos;</p>";
+        let html = "<p>&lt;tag &amp; test &#92; &#97; &#98; &#99;> &apos;</p>";
+
+        assert_eq!(
+            html.trim_end_matches('\n'),
+            crate::markdown::render(&md).unwrap().trim_end_matches('\n')
+        );
+
+    }
+
+    #[test]
+    fn escape_test2() {
+
+        let md = "*escaped\\* `\\not escaped` \\`escaped`".to_string();
+        let html = "<p>*escaped&#42; <code class=\"short\">\\not escaped</code> &#96;escaped`</p>"; // ..later!
 
         assert_eq!(
             html.trim_end_matches('\n'),
@@ -60,7 +73,15 @@ mod tests {
     #[test]
     fn paragraph_test() {
         let md = "p1\np1\n\np2\np2  \np2\n\np3\np3".to_string();
-        let html = "<p>p1 p1</p>\n\n<p>p2 p2  <br />p2</p>\n\n<p>p3 p3</p>";
+        let html = "<p>p1 p1</p>\n\n<p>p2 p2<br />p2</p>\n\n<p>p3 p3</p>";
+
+        assert_eq!(
+            html.trim_end_matches('\n'),
+            crate::markdown::render(&md).unwrap().trim_end_matches('\n')
+        );
+
+        let md = "p1\np1\n\np2\np2\\\np2\n\np3\np3".to_string();
+        let html = "<p>p1 p1</p>\n\n<p>p2 p2<br />p2</p>\n\n<p>p3 p3</p>";
 
         assert_eq!(
             html.trim_end_matches('\n'),
